/*
 * Programmer:  Timothy E. Hoff
 * File Name:   environ.c
 * Written:     July 9, 1996
 * Modified:
 * Description: This module loads environmental variables from
 *              a file consisting of entries (name=value).
 *              Each entry must begin on its own line but 
 *              may be continued by escaping the newline
 *              character.
 *
 * Copyright (c) 1996, Timothy E. Hoff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */


#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include "log.h"
#include "input.h"
#include "sizes.h"
#include "error.h"

#ifndef _LINT
static char rcsid[] = "$Id";
#endif

#define nextvar(fp) getattr(fp)
 

int load_environ(char *pathname)
{
    FILE *fp;
    char *envar;
    char msg[BUFSIZE];
    char *name, *value;

    if ((fp = openfile(pathname, "root")) != NULL) {
        while ((envar = nextvar(fp)) != NULL) {
            if ((name = strtok(envar, "=")) != NULL) {
                value = strtok(NULL, "");
                setenv(name, value, 1);
            } else {
              /*
               * This code should never execute because input.c
               * should filter all bad input.
               */
              sprintf(msg, "Environment must be \"name=value\"");
              log_error(ESYNTAX, msg);
              return -1;
            }
        }
    } else {
        sprintf(msg, "Could not open environment [%s].", pathname);
        log_error(ENOENT, msg);
        return -1;
    }

    if (feof(fp))
        return 0;
    else 
        return -1;
}


